@@ -103,13 +103,6 @@ func TestExpandRegexpMatchInString(t *testing.T) {
 			input:    "ref+vault://srv/foo/bar\n",
 			expected: "vault-srv-/foo/bar\n",
 		},
-		{
-			name:     "it should not match closing quotes when using query params",
-			regex:    DefaultRefRegexp,
-			only:     []string{"ref", "secretref"},
-			input:    "\"ref+awsssm://srv/foo/bar?mode=singleparam\"",
-			expected: "\"awsssm-srv-/foo/bar\"",
-		},
 		{
 			name:     "it should match greedily upto a space when using query params",
 			regex:    DefaultRefRegexp,
@@ -124,6 +117,13 @@ func TestExpandRegexpMatchInString(t *testing.T) {
 			input:    "ref+awsssm://srv/foo/bar?mode=singleparam some-string ref+awsssm://srv/foo/bar?mode=singleparam",
 			expected: "awsssm-srv-/foo/bar some-string awsssm-srv-/foo/bar",
 		},
+		{
+			name:     "it should handle quoted values in query",
+			regex:    DefaultRefRegexp,
+			only:     []string{"ref", "secretref"},
+			input:    "ref+tfstategs://foo/bar.tfstate/state[\"value\"].value",
+			expected: "tfstategs-foo-/bar.tfstate/state[\"value\"].value",
+		},
 	}
 
 	for i := range testcases {
